package com.ruoyi.web.modules.architecture.mapper;

import java.util.List;
import com.ruoyi.web.modules.architecture.domain.BizEpidemicTreatmentStandard;

/**
 * 疫病诊疗标准 Mapper
 */
public interface BizEpidemicTreatmentStandardMapper
{
    BizEpidemicTreatmentStandard selectBizEpidemicTreatmentStandardById(Long id);

    List<BizEpidemicTreatmentStandard> selectBizEpidemicTreatmentStandardList(BizEpidemicTreatmentStandard query);

    int insertBizEpidemicTreatmentStandard(BizEpidemicTreatmentStandard row);

    int updateBizEpidemicTreatmentStandard(BizEpidemicTreatmentStandard row);

    int deleteBizEpidemicTreatmentStandardById(Long id);

    int deleteBizEpidemicTreatmentStandardByIds(Long[] ids);
}
